@@ -123,6 +123,8 @@ class TextRefBaseClass:
         o  _refsubpart_separator = "."
 
         METHODS:
+        o  __eq__(self, textref)
+        o  __hash__(self)
         o  __init__(self, definition=None, no_mono_ref2=False)
         o  __iter__(self)
         o  __str__(self)
@@ -197,6 +199,34 @@ class TextRefBaseClass:
     _ref2ref_separator = "-"
     _refsubpart_separator = "."
 
+    def __eq__(self,
+               textref):
+        """
+            TextRefBaseClass.__eq__()
+
+            TextRef* can be used directly as keys in dict, hence this method.
+            ___________________________________________________________________
+
+            ARGUMENT:
+            o  textref: a TextRef* class
+
+            RETURNED VALUE: (bool)
+                see https://docs.python.org/3/reference/datamodel.html#object.__eq__
+        """
+        return self.definition == textref.definition
+
+    def __hash__(self):
+        """
+            TextRefBaseClass.__hash__()
+
+            TextRef* can be used directly as keys in dict, hence this method.
+            ___________________________________________________________________
+
+            RETURNED VALUE: (int)
+                see https://docs.python.org/3/reference/datamodel.html#object.__hash__
+        """
+        return hash(self.definition)
+
     def __init__(self,
                  definition=None,
                  no_mono_ref2=False):
